# build.tcl

# STEP#1: setup design sources and constraints

read_verilog VGATop.v
read_verilog VGASync.v
read_verilog VGAColourCycle.v

read_xdc Basys3_Master.xdc

set_property PART xc7a35tcpg236-1 [current_project]
set_property BOARD_PART digilentinc.com:basys3:part0:1.1 [current_project]
set_property TARGET_LANGUAGE Verilog [current_project]

# STEP#2: generate IP

create_ip -name clk_wiz -vendor xilinx.com -library ip -version 5.4 -module_name clk_wiz_0
set_property -dict [list				\
	CONFIG.CLKOUT1_REQUESTED_OUT_FREQ {25}		\
	CONFIG.USE_LOCKED {false}			\
	CONFIG.MMCM_DIVCLK_DIVIDE {1}			\
	CONFIG.MMCM_CLKFBOUT_MULT_F {9.125}		\
	CONFIG.MMCM_CLKOUT0_DIVIDE_F {36.500}		\
	CONFIG.CLKOUT1_JITTER {181.828}			\
	CONFIG.CLKOUT1_PHASE_ERROR {104.359}]		\
	[get_ips clk_wiz_0]

generate_target {instantiation_template} [get_files clk_wiz_0.xci]

# STEP#3: synthesize IP

synth_ip -force [get_files clk_wiz_0.xci]

# STEP#4: synthesize design

synth_design -top VGATop

# STEP#5: optimize and place design

opt_design
place_design

# STEP#6: route design

route_design

report_timing -no_header -path_type summary -max_paths 1000 -slack_lesser_than 0 -setup
report_timing -no_header -path_type summary -max_paths 1000 -slack_lesser_than 0 -hold

# STEP#7: generate bitstream

set_property CONFIG_VOLTAGE 3.3 [current_design]
set_property CFGBVS VCCO [current_design]

write_bitstream -force part1

# STEP#8: generate reports

report_clocks

report_utilization -hierarchical -file utilization.rpt
report_clock_utilization -file utilization.rpt -append
report_datasheet -file datasheet.rpt
report_timing_summary -file timing.rpt

puts "MESSAGE: build done."
